﻿using System;
using System.Web.Mvc;

// Add the following "using" statements
using System.ServiceModel;
using HelloAzureService;
using AzureWebRole.Models;
using Microsoft.WindowsAzure.ServiceRuntime;

namespace AzureWebRole.Controllers
{
    public class HomeController : Controller
    {
        // Add a constant to hold the view message
        const string ScreenMessage = "Welcome to my managed deploy Azure application!";

        public ActionResult Index()
        {
            // Change the code below to use the constant
            ViewBag.Message = ScreenMessage;

            // Polulate an instance of the HomePageModel class 
            var model = new HomePageModel
            {
                StringReversalValue = "Hello World!",
                SecondsLeftValue = "",
                CommunicationChannel = "",
                RomanNumerals = "",
                IntegerToConvert = DateTime.Now.Year.ToString()
            };

            return View(model);
        }


    [HttpPost]
    public ActionResult Index(string btnName)
    {
        ViewBag.Message = ScreenMessage;

        var model = new HomePageModel
        {
            StringReversalValue = Request.Form["StringReversal"],
            SecondsLeftValue = Request.Form["SecondsLeft"],
            CommunicationChannel = Request.Form["CommChannel"],
            IntegerToConvert = Request.Form["IntegerToConvert"],
            RomanNumerals = Request.Form["RomanNumerals"]

        };

        var roles = RoleEnvironment.Roles["AzureWorkerRole"];
        var workRoleInternalEndPoint = roles.Instances[0]
            .InstanceEndpoints["Internal"];
        var binding = new NetTcpBinding(SecurityMode.None, false);
        var myEndpoint = new EndpointAddress(
            String.Format("net.tcp://{0}/Internal", 
                workRoleInternalEndPoint.IPEndpoint));

        var myChanFac = new ChannelFactory<IHelloWcf>(binding, myEndpoint);
        var myClient = myChanFac.CreateChannel();

        // Call the appropriate service based on the button pressed
        switch (btnName)
        {
            case "Reverse Text":
                model.StringReversalValue = 
                    myClient.ReverseThisString(model.StringReversalValue);
                break;

            case "Roman Numerals":
                int integerToConvert;
                var resultOfParseSucceeded = 
                    int.TryParse(Request.Form["IntegerToConvert"], 
                        out integerToConvert);

                if (resultOfParseSucceeded)
                {
                    model.IntegerToConvert = integerToConvert.ToString();
                    model.RomanNumerals = 
                        string.Format("Converted to: {0}", 
                            myClient.TranslateToRomanNumerals(
                                integerToConvert));
                }
                else
                {
                    model.IntegerToConvert = 
                        Request.Form["IntegerToConvert"];
                    model.RomanNumerals = 
                        "Error: you must enter a valid integer to convert.";
                }
                break;
            default:
                model.CommunicationChannel = 
                    myClient.GetCommunicationChannel();
                break;
        }

        return View(model);
    }


        public ActionResult About()
        {
            return View();
        }
    }
}
