﻿using System;
using System.Diagnostics;
using System.Net;
using System.Threading;
using Microsoft.WindowsAzure.ServiceRuntime;
// Add using System.ServiceModel below
using System.ServiceModel;
// Add using HelloAzureService below
using HelloAzureService;



namespace AzureWorkerRole
{
    public class WorkerRole : RoleEntryPoint
    {
        public override void Run()
        {
            // This is a sample worker implementation. 
            // Replace with your logic.
            Trace.WriteLine("AzureWorkerRole entry point called", 
                "Information");

            // Add the StartWcfService method call below
            StartWcfService();

            while (true)
            {
                Thread.Sleep(10000);
                Trace.WriteLine("Working", "Information");
            }
        }

        public override bool OnStart()
        {
            // Set the maximum number of concurrent connections 
            ServicePointManager.DefaultConnectionLimit = 12;

            // For information on handling configuration changes
            // see the MSDN topic at http://go.microsoft.com/fwlink/?LinkId=166357.

            return base.OnStart();
        }

        // Add the StartWcfService method code below
        private static void StartWcfService()
        {
            Trace.TraceInformation("Starting WCF service host...");
            var serviceHost = new ServiceHost(typeof(HelloWcf));

            // Use NetTcpBinding with no security
            var binding = new NetTcpBinding(SecurityMode.None);

            //// Define an external endpoint for client traffic
            //var externalEndPoint =
            //    RoleEnvironment.CurrentRoleInstance
            //        .InstanceEndpoints["External"];

            //serviceHost.AddServiceEndpoint(
            //   typeof(IHelloWcf),
            //   binding,
            //   String.Format("net.tcp://{0}/External",
            //        externalEndPoint.IPEndpoint));

            // Define an internal endpoint for inter-role traffic
            var internalEndPoint =
                RoleEnvironment.CurrentRoleInstance
                    .InstanceEndpoints["Internal"];

            serviceHost.AddServiceEndpoint(
               typeof(IHelloWcf),
               binding,
               String.Format("net.tcp://{0}/Internal",
                    internalEndPoint.IPEndpoint));

            try
            {
                serviceHost.Open();
                Trace.TraceInformation(
                    "WCF service host started successfully.");
            }
            catch (TimeoutException timeoutException)
            {
                Trace.TraceError("The service operation timed out. {0}",
                                 timeoutException.Message);
            }
            catch (CommunicationException communicationException)
            {
                Trace.TraceError("Could not start WCF service host. {0}",
                                 communicationException.Message);
            }
        }
    }
}
