﻿using System;
using System.Collections.Generic;
using System.Linq;

// Add System.ServiceModel below
using System.ServiceModel;
using System.Text;

namespace HelloAzureService
{
    // Add the ServiceContract below
    [ServiceContract]
    public interface IHelloWcf
    {
        [OperationContract]
        string ReverseThisString(string stringToReverse);

        [OperationContract]
        string TranslateToRomanNumerals(int valueToConvert);

        [OperationContract]
        string GetCommunicationChannel();
    }

    // Add the HelloWcf class below
    public class HelloWcf : IHelloWcf
    {
        /// <summary>
        /// Simple string value reversal
        /// </summary>
        /// <param name="stringToReverse">String value to reverse</param>
        /// <returns>reversed string value</returns>
        public string ReverseThisString(string stringToReverse)
        {
            var reversed = stringToReverse.Reverse().ToArray();

            var stringOut = new string(reversed);

            return stringOut;
        }

        /// <summary>
        /// Translate an integer to Roman Numberals
        /// </summary>
        /// <param name="valueToConvert">the integer to convert</param>
        /// <returns>converted Roman Numeral value</returns>
        public string TranslateToRomanNumerals(int valueToConvert)
        {
            var romanNumerals = new Dictionary<string, int>
                                    {
                                        {"M", 1000},
                                        {"CM", 900},
                                        {"D", 500},
                                        {"CD", 400},
                                        {"C", 100},
                                        {"XC", 90},
                                        {"L", 50},
                                        {"XL", 40},
                                        {"X", 10},
                                        {"IX", 9},
                                        {"V", 5},
                                        {"IV", 4},
                                        {"I", 1}
                                    };

            var convertedRomanNumerals = new StringBuilder();

            for (var i = 0; valueToConvert > 0; i++)
            {
                while (romanNumerals.ElementAt(i).Value <= valueToConvert)
                {
                    convertedRomanNumerals.Append(
                        romanNumerals.ElementAt(i).Key);
                    valueToConvert -= romanNumerals.ElementAt(i).Value;
                }
            }

            return convertedRomanNumerals.ToString();
        }


        /// <summary>
        /// Return the channel between the client & the server
        /// </summary>
        /// <returns>The communications channel the Web Role and Worker Role 
        /// are communicating through</returns>
        public string GetCommunicationChannel()
        {
            return (string.Format("Internal communications channel: {0}", 
                OperationContext.Current.Channel.LocalAddress.Uri));
        }
    }
}
